@@ -1,6 +1,6 @@
 package App::digitdemog ; 
-our $VERSION = '0.050' ; 
-our $DATE = '2021-06-13T17:55+09:00' ; 
+our $VERSION = '0.060' ; 
+our $DATE = '2021-07-01T19:27+09:00' ; 
 
 =encoding utf8
 
@@ -11,19 +11,17 @@ App::digitdemog
 =head1 SYNOPSIS
 
 This module provides a Unix-like command `digitdemog'. 
-(And also "strgroup" that is still on developing, which may be integrated into `digitdemog'.)
 
 =head1 DESCRIPTION
 
 想定している使い方 (digitdemog) : 
 
   1. 何桁目にどんな文字が現れたのかを解読する
-  2. -L により、各行の桁数ごとに、どんな値が現れたか、例を取り出す。
+  2. -L2 により、各行の桁数ごとに、どんな値が現れたか、例を取り出す。
  
 =head1 SEE ALSO
 
 digitdemog --help 
-strgourp --help
 
  Copyright (c) 2021 Toshiyuki SHIMONO. All rights reserved.
  This program is free software; you can redistribute it and/or
